@@ -8,16 +8,13 @@ from laboro.vault import Vault
 
 
 def run(workflow, context):
-  logging.info(f"[+] Preparing workflow environment: {workflow}")
   with Workflow(name=workflow, context=context) as wkf:
     wkf.run()
 
 
 def main(workflows):
-  vault = Vault()
-  logmgr = LogMgr(vault)
+  context = Context(logger=LogMgr(Vault()))
   logging.getLogger().log_section("LABORO", "Bootstrapping")
-  context = Context(logger=logmgr)
   for workflow in workflows:
     logging.getLogger().vault.clear()
     run(workflow, context=context)
